@@ -3,12 +3,10 @@ BEGIN {
   $Dist::Zilla::PluginBundle::AMD::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Dist::Zilla::PluginBundle::AMD::VERSION = '0.006';
+  $Dist::Zilla::PluginBundle::AMD::VERSION = '0.007';
 }
 # ABSTRACT: Build your distributions like AMD does
 
-
-
 use Moose 1.00;
 use Method::Signatures::Simple;
 use Moose::Util::TypeConstraints;
@@ -341,7 +339,7 @@ method configure {
             do_metadata => 1,
         }],
         [EOLTests => {
-            trailing_whitespace => !$self->disable_trailing_whitespace_tests,
+            trailing_whitespace => $self->disable_trailing_whitespace_tests ? 0 : 1,
         }],
     );
 
@@ -356,7 +354,7 @@ method configure {
     $self->add_plugins('AutoPrereqs') if $self->auto_prereqs;
 
 
-
+    $self->add_plugins('Git::Describe');
     $self->add_plugins('CheckChangesHasContent');
 
     $self->add_plugins(['NextRelease' =>
@@ -433,6 +431,7 @@ It is roughly equivalent to:
   config_plugin = @AMD
 
   [AutoPrereqs]
+  [Git::Describe]
 
   [CheckChangesHasContent]
 
